lastPayload property
P?
get
lastPayload
get the latest payload if exists else returns null
Implementation
P? get lastPayload => event.lastPayload;
get the latest payload if exists else returns null
P? get lastPayload => event.lastPayload;