fire method
Fire the payload to all listeners.
if useHistory is true then the payload will be added to history
use delay to delay fire
set silent to true to only add payload to lists without calling listeners
for more information check docs for Event.fire
Implementation
void fire(
P payload, {
bool useHistory = true,
Duration? delay,
bool silent = false,
}) =>
event.fire(payload, useHistory: useHistory, delay: delay, silent: silent);